@@ -509,7 +509,6 @@ def relabel_selinux(new_fs):
                  "/etc/selinux/targeted/contexts/files/file_contexts.local"]
 
     dirs = ["/etc",
-            "/usr/bin",
             "/usr/bin",
             "/usr/sbin",
             "/usr/share",
@@ -518,7 +517,6 @@ def relabel_selinux(new_fs):
     exclude_dirs = ["/usr/share/factory"]
 
     # Reduce the list to something subprocess can use directly
-    excludes = sum([["-e", d] for d in exclude_dirs], [])
 
     new_root = new_fs.path("/")
 
@@ -529,10 +527,13 @@ def relabel_selinux(new_fs):
                                rbind=True):
             for fc in ctx_files:
                 if os.path.exists(new_root + "/" + fc):
-                    dom.runcon(["setfiles", "-v", "-r", new_fs.path("/"),
-                                fc] +
+                    excludes = sum([["-e", "{}/{}".format(new_root, d)]
+                                    for d in exclude_dirs], [])
+                    run_dirs = [new_root + d for d in dirs]
+                    dom.runcon(["setfiles", "-v", "-r", new_root,
+                                new_root + fc] +
                                excludes +
-                               dirs)
+                               run_dirs)
                 else:
                     log.debug("{} not found in new fs, skipping".format(fc))
 
